@@ -32,6 +32,11 @@
    libisoburn.h. One should not mix those calls with the ones of xorriso.h .
 */
 
+/* Important: If you add a public API function then add its name to file
+                  libisoburn/libisoburn.ver
+*/
+
+
 #ifndef Xorriso_includeD
 #define Xorriso_includeD yes
 
@@ -56,7 +61,7 @@ struct XorrisO;
 */
 #define Xorriso_header_version_majoR  0
 #define Xorriso_header_version_minoR  6
-#define Xorriso_header_version_micrO  0
+#define Xorriso_header_version_micrO  4
 
 
 /** Eventually something like ".pl01" to indicate a bug fix. Normally empty.
@@ -110,7 +115,7 @@ void Xorriso__version(int *major, int *minor, int *micro);
     @param flag Bitfield for control purposes. Unused yet. Submit 0.
     @return 1= library can work for caller
             0= library is not usable in some aspects. Caller must restrict
-               itself to an earlier API version or must not use this libray
+               itself to an earlier API version or must not use this library
                at all.
 */
 int Xorriso__is_compatible(int major, int minor, int micro, int flag);
@@ -185,7 +190,7 @@ int Xorriso_startup_libraries(struct XorrisO *xorriso, int flag);
          functions from the Options API.
 
          Wenn all desired activities are done, you may check whether there are
-         uncommited chages pending, compute an exit value, destroy the XorrisO
+         uncommited changes pending, compute an exit value, destroy the XorrisO
          object, and exit your program.
 */
 
@@ -290,8 +295,9 @@ int Xorriso_program_arg_bsl(struct XorrisO *xorriso, int argc, char ***argv,
                   be at least 1, argv[*idx] must be a command.
                   *idx will iterate over commands and parameters until this
                   function aborts or until argc is reached.
-   @param flag    bit0= recursion
-                  bit1= these are the main() program start arguments
+   @param flag    bit0= reserved. Indicates recursion. Submit 0. 
+                  bit1= Indicates that these are the main() program start
+                        arguments
    @return <=0 = error
              1 = success
              2 = problem event ignored
@@ -348,8 +354,9 @@ int Xorriso_dialog(struct XorrisO *xorriso, int flag);
                       A final newline character gets appended automatically.
     @param os_errno   Eventual errno related to the message. Submit 0 if
                       the message is not related to a operating system error.
-    @param severity   One of "ABORT", "FATAL", "SORRY", "WARNING", "HINT",
-                      "NOTE", "UPDATE", "DEBUG". Defaults to "FATAL".
+    @param severity   One of "ABORT", "FATAL", "FAILURE", "MISHAP", "SORRY",
+                      "WARNING", "HINT", "NOTE", "UPDATE", "DEBUG".
+                      Defaults to "FATAL".
     @param flag       Bitfield for control purposes
                         bit0= use pager (as with result)
                         bit1= permission to suppress output
@@ -555,15 +562,15 @@ int Xorriso_lst_destroy_all(struct Xorriso_lsT **lstring, int flag);
    Xorriso_eval_problem_status()
    One should follow its eventual advice to abort.
 
-   Options with a varying number of arguments get them passed like
+   Options with a varying number of arguments get then passed like
    Xorriso_interpreter(). E.g.:
      int Xorriso_option_add(struct XorrisO *xorriso, int argc, char **argv,
                             int *idx, int flag);
-   They begin to read the arguments at position *idx and will see the list
-   end either at the next argv which contains the -list_delimiter text or
-   at argv[argc-1]. After the call, *idx will be the index of the first not
-   yet interpreted argv.
-
+   The option functions will begin to read the arguments at position *idx
+   and will see the list end either at the next argv which contains the
+   -list_delimiter text or at argv[argc-1].
+   After the call, *idx will be the index of the first not yet interpreted
+   argv.
 */
 
 
@@ -596,6 +603,10 @@ int Xorriso_option_alter_date(struct XorrisO *xorriso,
                               char *time_type, char *timestring,
                               int argc, char **argv, int *idx, int flag);
 
+/* Option -append_partition */
+int Xorriso_option_append_partition(struct XorrisO *xorriso, char *partno_text,
+                                  char *type_text, char *image_path, int flag);
+
 /* Option -application_id */
 int Xorriso_option_application_id(struct XorrisO *xorriso, char *name, 
                                   int flag);
@@ -847,6 +858,10 @@ int Xorriso_option_history(struct XorrisO *xorriso, char *line, int flag);
 int Xorriso_option_iso_rr_pattern(struct XorrisO *xorriso, char *mode,
                                   int flag);
 
+/* Option -jigdo aspect argument */
+int Xorriso_option_jigdo(struct XorrisO *xorriso, char *aspect, char *arg,
+                         int flag);
+
 /* Option -joliet "on"|"off" */
 int Xorriso_option_joliet(struct XorrisO *xorriso, char *mode, int flag);
 
@@ -995,6 +1010,9 @@ int Xorriso_option_pathspecs(struct XorrisO *xorriso, char *mode, int flag);
 /* Option -pkt_output */
 int Xorriso_option_pkt_output(struct XorrisO *xorriso, char *mode, int flag);
 
+/* Option -preparer_id */
+int Xorriso_option_preparer_id(struct XorrisO *xorriso, char *name, int flag);
+
 /* Option -print */
 int Xorriso_option_print(struct XorrisO *xorriso, char *text, int flag);
 
@@ -1030,10 +1048,6 @@ int Xorriso_option_read_mkisofsrc(struct XorrisO *xorriso, int flag);
 /* Option -reassure "on"|"tree"|"off" */
 int Xorriso_option_reassure(struct XorrisO *xorriso, char *mode, int flag);
 
-/* Option -relax_compliance */
-int Xorriso_option_relax_compliance(struct XorrisO *xorriso, char *mode,
-                                    int flag);
-
 /* Option -report_about */
 int Xorriso_option_report_about(struct XorrisO *xorriso, char *severity, 
                                 int flag);
@@ -1042,9 +1056,6 @@ int Xorriso_option_report_about(struct XorrisO *xorriso, char *severity,
 int Xorriso_option_return_with(struct XorrisO *xorriso, char *severity,
                                int exit_value, int flag);
 
-/* Option -revoke_exclusions */
-int Xorriso_option_revoke_exclusions(struct XorrisO *xorriso, int flag);
-
 /* Options -rm alias -rmi , -rm_r alias -rm_ri , -rmdir alias -rmdiri */
 /* @param flag bit0=recursive , bit2= remove empty directory: rmdir */
 int Xorriso_option_rmi(struct XorrisO *xorriso, int argc, char **argv,
